ptolemy: efficient rasterizing of shapefiles
============================================

.. image:: https://github.com/gidden/ptolemy/workflows/ci/badge.svg?branch=main
    :target: https://github.com/gidden/ptolemy/actions?workflow=ci
    :alt: CI

.. image:: https://codecov.io/gh/gidden/ptolemy/branch/main/graph/badge.svg
    :target: https://codecov.io/gh/gidden/ptolemy
    :alt: Codecov

.. image:: https://img.shields.io/readthedocs/ptolemy-iamc/latest?label=Read%20the%20Docs
    :target: https://ptolemy-iamc.readthedocs.io/en/latest/
    :alt: Read the Docs

.. image:: https://img.shields.io/pypi/v/ptolemy-iamc
    :target: https://pypi.org/project/ptolemy-iamc/
    :alt: PyPI


Summary
-------

Ptolemy provides support capabilities for rasterizing shapefiles on to grids. 

Check out the `documentation`_

Issues and Discussions
----------------------

As usual for any GitHub-based project, raise an `issue`_ if you find any bug or
want to suggest an improvement, or open a discussion if you want to discuss.


.. _PyPI: https://pypi.org
.. _latest branch: https://github.com/gidden/ptolemy/tree/latest
.. _master branch: https://github.com/gidden/ptolemy/tree/master
.. _tox: https://tox.readthedocs.io/en/latest/
.. _ReadTheDocs: https://readthedocs.org/
.. _issue: htts://github.com/gidden/ptolemy/issues/new
.. _documentation: https://ptolemy-iamc.readthedocs.io/en/latest/
